import { defineStore } from 'pinia'
import { ref } from 'vue'

export const useAuthStore = defineStore('auth', () => {
  // 从 localStorage 获取初始状态
  const isLoggedIn = ref(!!localStorage.getItem('token'))
  const hasCompletedOnboarding = ref(JSON.parse(localStorage.getItem('hasCompletedOnboarding') || 'false'))
  const token = ref(localStorage.getItem('token'))
  const isNewUser = ref(false) // 默认不是新用户

  function setToken(newToken: string, newStatus: boolean) {
    token.value = newToken
    isLoggedIn.value = true
    isNewUser.value = newStatus
    localStorage.setItem('token', newToken)
    localStorage.setItem('isLoggedIn', 'true') // 保留旧的isLoggedIn以便兼容
  }

  function login() {
    // 这个方法在 setToken 后可以被视为一个辅助方法或被废弃
    isLoggedIn.value = true
    localStorage.setItem('isLoggedIn', 'true')
  }

  function logout() {
    token.value = null
    isLoggedIn.value = false
    isNewUser.value = false
    hasCompletedOnboarding.value = false
    localStorage.removeItem('token')
    localStorage.removeItem('isLoggedIn')
    localStorage.removeItem('hasCompletedOnboarding')
  }

  function completeOnboarding() {
    hasCompletedOnboarding.value = true
    localStorage.setItem('hasCompletedOnboarding', 'true')
  }

  async function setPassword(newPassword: string) {
    if (!token.value) {
      throw new Error('用户未登录');
    }
    const response = await fetch('http://localhost:8000/api/v1/auth/users/me/password', {
      method: 'PUT',
      headers: {
        'Content-Type': 'application/json',
        'Authorization': `Bearer ${token.value}`
      },
      body: JSON.stringify({
        new_password: newPassword
      })
    });

    if (!response.ok) {
      const errorData = await response.json();
      throw new Error(errorData.detail || '密码设置失败');
    }

    return await response.json();
  }
  async function passwordLogin(phoneNumber: string, password: string) {
    const response = await fetch('http://localhost:8000/api/v1/auth/login/password', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
      },
      body: JSON.stringify({
        phone_number: phoneNumber,
        password: password
      })
    });

    if (!response.ok) {
      const errorData = await response.json();
      throw new Error(errorData.detail || '手机号或密码错误');
    }

    const data = await response.json();
    setToken(data.access_token, data.is_new_user);
    
    if (data.has_completed_onboarding) {
      completeOnboarding();
    }
  }

  return {
    isLoggedIn,
    hasCompletedOnboarding,
    token,
    isNewUser,
    setToken,
    login,
    logout,
    completeOnboarding,
    setPassword,
    passwordLogin,
  }
})